# eric7.Snapshot.SnapshotModes

Module implementing the snapshot mode enumeration.

### Global Attributes

None

### Classes

SnapshotModes | Class implementing the snapshot modes.

### Functions

None

## SnapshotModes

Class implementing the snapshot modes.

### Derived from

enum.Enum

### Class Attributes

ELLIPSE
FREEHAND
FULLSCREEN
RECTANGLE
SELECTEDSCREEN
SELECTEDWINDOW

### Class Methods

None

### Methods

None

### Static Methods

None

Up